wget https://img.shields.io/conda/vn/conda-forge/pybind11.svg               -O images/pybind11_conda.svg
wget https://img.shields.io/pypi/v/pybind11.svg                             -O images/pybind11_pypi.svg
wget https://img.shields.io/pypi/pyversions/pybind11.svg                    -O images/pybind11_pyversions.svg
wget https://repology.org/badge/latest-versions/python:pybind11.svg         -O images/pybind11_lastest.svg
wget https://github.com/pybind/pybind11/raw/master/docs/pybind11-logo.png   -O images/pybind11-logo.png
wget https://ci.appveyor.com/api/projects/status/riaj54pn4h08xy40?svg=true  -O images/build_passing_riaj54pn4h08xy40.svg
wget https://github.com/pybind/pybind11/workflows/CI/badge.svg              -O images/badge.svg
wget https://img.shields.io/gitter/room/gitterHQ/gitter.svg                 -O images/gitter.svg
wget https://readthedocs.org/projects/pybind11/badge?version=latest         -O images/docspassing.svg
wget https://img.shields.io/badge/docs-stable-blue.svg                      -O images/docs-stable.svg
